'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getElement = exports.getContainerElement = exports.getClassName = exports.delay = exports.styleElement = exports.flippyTailClass = exports.callAll = exports.onUserInputChange = exports.lightenDarken = exports.capitalizeEveryWord = exports.flippyMultiTail = exports.flippyMultiBase = exports.unflippyMultiBase = exports.compose = undefined;

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

var _entries = require('babel-runtime/core-js/object/entries');

var _entries2 = _interopRequireDefault(_entries);

exports.flippyClass = flippyClass;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var compose = exports.compose = function compose() {
  for (var _len = arguments.length, fns = Array(_len), _key = 0; _key < _len; _key++) {
    fns[_key] = arguments[_key];
  }

  return function (x) {
    return fns.reduceRight(function (v, f) {
      return f(v);
    }, x);
  };
};

function flippyClass(bool, base, truthy, falsy) {
  return base + ' ' + (bool ? base + '--' + truthy : base + '--' + falsy);
}

var unflippyMultiBase = exports.unflippyMultiBase = function unflippyMultiBase(bases, tail) {
  var output = [];
  bases.forEach(function (base) {
    if (base) {
      output.push(base + ' ' + base + '--' + tail);
    }
  });
  return output.join(' ');
};

var flippyMultiBase = exports.flippyMultiBase = function flippyMultiBase(bool, unflattenedBases, truthy, falsy) {
  var output = [];
  var run = function run(bases) {
    bases.forEach(function (base) {
      if (base) {
        if (Array.isArray(base)) {
          run(base);
        } else {
          output.push(flippyClass(bool, base, truthy, falsy));
        }
      }
    });
  };
  run(unflattenedBases);
  return output.join(' ');
};

var flippyMultiTail = exports.flippyMultiTail = function flippyMultiTail(base) {
  for (var _len2 = arguments.length, args = Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
    args[_key2 - 1] = arguments[_key2];
  }

  var modified = [base];
  args.forEach(function (arr) {
    var mod = '' + (arr[0] ? base + '--' + arr[1] : base + '--' + arr[2]);
    modified.push(mod);
  });

  return modified.join(' ');
};

var capitalizeEveryWord = exports.capitalizeEveryWord = function capitalizeEveryWord(str) {
  return str ? str.replace(/\b[a-z]/g, function (char) {
    return char.toUpperCase();
  }) : 'error: string undefined';
};

var lightenDarken = exports.lightenDarken = function lightenDarken(color, amount) {
  var usePound = false;

  if (color[0] == '#') {
    color = color.slice(1);
    usePound = true;
  }

  var num = parseInt(color, 16);

  var r = (num >> 16) + amount;

  if (r > 255) r = 255;else if (r < 0) r = 0;

  var b = (num >> 8 & 0x00ff) + amount;

  if (b > 255) b = 255;else if (b < 0) b = 0;

  var g = (num & 0x0000ff) + amount;

  if (g > 255) g = 255;else if (g < 0) g = 0;

  return (usePound ? '#' : '') + (g | b << 8 | r << 16).toString(16);
};
var onUserInputChange = exports.onUserInputChange = function onUserInputChange(callback) {
  //console.log(`onUserInputChange`)
  var type = 'mouse',
      lastTime = 0;
  var mousemoveHandler = function mousemoveHandler() {
    var now = performance.now();
    if (now - lastTime < 20) type = 'mouse', callback(type), document.removeEventListener('mousemove', mousemoveHandler);
    lastTime = now;
  };
  document.addEventListener('touchstart', function () {
    if (type === 'touch') return;type = 'touch', callback(type), document.addEventListener('mousemove', mousemoveHandler);
  });
};

var callAll = exports.callAll = function callAll() {
  for (var _len3 = arguments.length, fns = Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
    fns[_key3] = arguments[_key3];
  }

  return function () {
    for (var _len4 = arguments.length, args = Array(_len4), _key4 = 0; _key4 < _len4; _key4++) {
      args[_key4] = arguments[_key4];
    }

    return fns.forEach(function (fn) {
      return fn && fn.apply(undefined, args);
    });
  };
};

var flippyTailClass = exports.flippyTailClass = function flippyTailClass(base) {
  for (var _len5 = arguments.length, args = Array(_len5 > 1 ? _len5 - 1 : 0), _key5 = 1; _key5 < _len5; _key5++) {
    args[_key5 - 1] = arguments[_key5];
  }

  var tail = [];
  args.forEach(function (arr) {
    var mod = '' + (arr[0] ? '--' + arr[1] : '--' + arr[2]);
    tail.push(mod);
  });
  return base + ' ' + base + tail.join('');
};

var styleElement = exports.styleElement = function styleElement(element, style) {
  if (document.querySelector(element)) {
    (0, _entries2.default)(style).map(function (valuePair) {
      var _valuePair = (0, _slicedToArray3.default)(valuePair, 2),
          key = _valuePair[0],
          value = _valuePair[1];

      document.querySelector(element).style[key] = value;
    });
  }
};

var delay = exports.delay = function delay(timeout) {
  return new _promise2.default(function (resolve) {
    setTimeout(resolve, timeout);
  });
};

var getClassName = exports.getClassName = function getClassName(base, extra, override) {
  return extra ? base + ' ' + extra : override ? override : base;
};

var getContainerElement = exports.getContainerElement = function getContainerElement(_ref) {
  var props = _ref.props;
  var containerClass = props.containerClass,
      containerRef = props.containerRef;

  return getElement({ ref: containerRef, className: containerClass });
};
var getElement = exports.getElement = function getElement(_ref2) {
  var ref = _ref2.ref,
      className = _ref2.className,
      id = _ref2.id,
      debug = _ref2.debug;

  var element = void 0;
  if (id) {
    element = document.getElementById(id);
    debug && console.log('element via id: ', element);
  } else if (className) {
    element = document.querySelector(className);
    debug && console.log('element via class: ', element);
  } else if (ref.current) {
    element = ref.current;
    debug && console.log('element via ref: ', element);
  } else {
    debug && console.error('must specify either className or ref');
  }
  return element;
};